@@ -1,7 +1,7 @@
 package App::PermuteNamed;
 
-our $DATE = '2016-09-26'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-01-29'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -39,6 +39,11 @@ _
             pos => 0,
             greedy => 1,
         },
+        separator => {
+            summary => 'Separator character to use',
+            schema => 'str*',
+            cmdline_aliases => {s => {}},
+        },
     },
     examples => [
         {
@@ -55,6 +60,7 @@ sub permute_named {
     require Permute::Named::Iter;
 
     my %args = @_;
+    my $sep = $args{separator};
 
     my @fields;
     my @permute;
@@ -64,13 +70,22 @@ sub permute_named {
         push @fields, $k
     }
 
+    my $resmeta = {};
     my $iter = Permute::Named::Iter::permute_named_iter(@permute);
     my @res;
     while (my $h = $iter->()) {
-        push @res, $h;
+        if (defined $sep) {
+            push @res, join($sep, @{$h}{@fields});
+        } else {
+            push @res, $h;
+        }
     }
 
-    [200, "OK", \@res, {'table.fields'=>\@fields}];
+    unless (defined $sep) {
+        $resmeta->{'table.fields'} = \@fields;
+    }
+
+    [200, "OK", \@res, $resmeta];
 }
 
 1;
@@ -88,7 +103,7 @@ App::PermuteNamed - Permute multiple-valued key-value pairs
 
 =head1 VERSION
 
-This document describes version 0.002 of App::PermuteNamed (from Perl distribution App-PermuteNamed), released on 2016-09-26.
+This document describes version 0.003 of App::PermuteNamed (from Perl distribution App-PermuteNamed), released on 2017-01-29.
 
 =head1 FUNCTIONS
 
@@ -139,6 +154,10 @@ Arguments ('*' denotes required arguments):
 
 =item * B<aoaos>* => I<array[array[str]]>
 
+=item * B<separator> => I<str>
+
+Separator character to use.
+
 =back
 
 Returns an enveloped result (an array).
@@ -181,7 +200,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
